@@ -3,13 +3,18 @@
 #' Radviz uses Dimensional Anchors and the spring paradigm to project a multidimensional space in 2D.
 #' This allows for the quick visualization of large and complex datasets.
 #' 
+#' @example examples/example-do.radviz.R
 #' @examples
-#' data(iris)
-#' das <- c('Sepal.Length','Sepal.Width','Petal.Length','Petal.Width')
-#' S <- make.S(das)
-#' rv <- do.radviz(iris,S)
-#' plot(rv,point.shape=1,point.color=c('red','green','blue')[as.integer(iris$Species)])
+#' plot(rv,anchors.only=FALSE)
 #' 
 #' @docType package
 #' @name Radviz
+NULL
+
+#' Defunct Functions
+#'
+#' These functions are Defunct in this release of Radviz, they will be
+#' marked as Defunct and removed in a future version.
+#' @name Radviz-deprecated
+#' @keywords internal
 NULL
\ No newline at end of file
